@@ -117,8 +117,8 @@ def cli(ctx, username, password=None):
 @click.option("-u", "--username", help="Username")
 @click.option("-p", "--initpw", help="Initial password")
 @click.option("-m", "--mail", help="email address")
-@click.option("-g", "--firstname", help="given name of this user")
-@click.option("-s", "--familyname", help="surname of this user")
+@click.option("-f", "--firstname", help="given name of this user")
+@click.option("-l", "--lastname", help="surname of this user")
 @click.option("-d", "--description", help="Description about the purpose of this user")
 @pass_iam_credentials
 def person(
@@ -130,7 +130,7 @@ def person(
     initpw,
     mail,
     firstname,
-    familyname,
+    lastname,
     description,
 ):
 
@@ -150,7 +150,7 @@ def person(
                 description=description,
                 mail=mail,
                 firstname=firstname or person["firstname"],
-                familyname=familyname or person["familyname"],
+                lanstame=lastname or person["lastname"],
             )
         except ValueError as exc:
             raise ClickException(exc)
@@ -398,6 +398,8 @@ def get_guest(credentials, username):
         guest = iam.get_guest(username)
     except ConnectionError as exc:
         raise ClickException(f"Cannot connect to IAM webservice at {exc.request.url}")
+    except ValueError as exc:
+        raise ClickException(f"No such guest: {username}")
     print(json.dumps(guest.data, indent=4, sort_keys=True))
 
 
@@ -429,9 +431,9 @@ def extend_guest(credentials, end_date, months, username):
     help="Name of the admin group this guest should be connected to. Default: same as the technical user which is creating this guest.",
 )
 @click.option(
-    "-l",
+    "-o",
     "--host-leitzahl",
-    help="Leitzahl of host organization, see org.ethz.ch. Default: Leitzahl of the host.",
+    help="Leitzahl of host organization, see http://www.org.ethz.ch. Default: Leitzahl of the host.",
 )
 @click.option(
     "-c",
@@ -490,9 +492,25 @@ def update_guest(
         raise ClickException(f"Cannot connect to IAM webservice at {exc.request.url}")
 
 
+@guest.command("delete", help="delete an existing guest")
+@click.argument("username")
+@pass_iam_credentials
+def delete_guest(
+    credentials,
+    username,
+):
+
+    iam = login(credentials.username, credentials.password)
+    try:
+        iam.delete_guest(username=username)
+        click.echo(f"Guest {username} successfully deleted.")
+    except ConnectionError as exc:
+        raise ClickException(f"Cannot connect to IAM webservice at {exc.request.url}")
+
+
 @guest.command("new", help="create a new guest")
-@click.option("-g", "--firstname", required=True, help="given name")
-@click.option("-s", "--familyname", required=True, help="surname")
+@click.option("-f", "--firstname", required=True, help="given name")
+@click.option("-l", "--lastname", required=True, help="surname")
 @click.option("-m", "--mail", required=True, help="email address")
 @click.option("-d", "--description", required=True, help="")
 @click.option("-h", "--host-username", required=True, help="ETHZ Username of host")
@@ -500,25 +518,23 @@ def update_guest(
     "-a",
     "--host-admingroup",
     required=True,
-    help="Name of the admin group this guest should be connected to. Default: same as the technical user which is creating this guest.",
+    help="Name of the administrative group that hosts this guest.",
+)
+@click.option(
+    "-o",
+    "--host-leitzahl",
+    help="Leitzahl of host organization, see http://www.org.ethz.ch. If not provided, the leitzahl of the host will be used.",
+)
+@click.option(
+    "-c",
+    "--technical-contact",
+    help="email address of technical contact. If not provided, the email address of the host will be used.",
 )
 @click.option(
     "-b",
     "--birth-date",
     help="birthdate in YYYY-MM-DD format. Default: Today's date + year 2000",
 )
-@click.option(
-    "-l",
-    "--host-leitzahl",
-    required=True,
-    help="Leitzahl of host organization, see org.ethz.ch. Default: Leitzahl of the host.",
-)
-@click.option(
-    "-c",
-    "--technical-contact",
-    required=True,
-    help="email address of technical contact. Default: email of the host of this guest.",
-)
 @click.option(
     "-n",
     "--notification",
@@ -526,10 +542,10 @@ def update_guest(
     help="g=guest, h=host, t=technical contact. Use any combination of the 3 chars. ",
 )
 @click.option(
-    "--sd", "--start-date", help="Start date of guest (YYYY-DD-MM). Default: today"
+    "-s", "--start-date", help="Start date of guest (YYYY-DD-MM). Default: today"
 )
 @click.option(
-    "--ed", "--end-date", help="End date of guest (YYYY-MM-DD). Default: today+1 year"
+    "-e", "--end-date", help="End date of guest (YYYY-MM-DD). Default: today+1 year"
 )
 @click.option(
     "--init-password",
@@ -540,7 +556,7 @@ def update_guest(
 def new_guest(
     credentials,
     firstname,
-    familyname,
+    lastname,
     mail,
     description,
     birth_date,
@@ -549,8 +565,8 @@ def new_guest(
     technical_contact,
     host_admingroup,
     notification,
-    sd,
-    ed,
+    start_date,
+    end_date,
     init_password,
 ):
     iam = login(credentials.username, credentials.password)
@@ -558,19 +574,22 @@ def new_guest(
         pass
         guest = iam.new_guest(
             firstname=firstname,
-            familyname=familyname,
+            lastname=lastname,
             mail=mail,
+            birth_date=birth_date,
             host_username=host_username,
             host_admingroup=host_admingroup,
             description=description,
             technical_contact=technical_contact,
             notification=notification,
             host_leitzahl=host_leitzahl,
-            start_date=sd,
-            end_date=ed,
+            start_date=start_date,
+            end_date=end_date,
         )
     except ConnectionError as exc:
         raise ClickException(f"Cannot connect to IAM webservice at {exc.request.url}")
+    except ValueError as exc:
+        raise ClickException(exc) from exc
 
     ldap_password = gen_password()
     vpn_password = gen_password()
