@@ -1,4 +1,4 @@
-import copy
+import re
 import json
 from dataclasses import asdict, dataclass, field
 from datetime import date, datetime
@@ -32,7 +32,7 @@ map_iamfields2internal = {
     "employeetype": "type",
     "enddate": "end_date",
     "firstname": "firstname",
-    "lastname": "familyname",
+    "lastname": "lastname",
     "gender": "gender",
     "salutation": "title",
     "mail": "mail",
@@ -67,7 +67,7 @@ map_internal2iamfields = {
 
 map_iamlegacyfields2internal = {
     "firstname": "firstname",
-    "familyname": "familyname",
+    "familyname": "lastname",
     "title": "title",
     "description": "description",
     "email": "mail",
@@ -125,7 +125,7 @@ guest_properties_update = [
 @dataclass
 class Person(IAMApi):
     firstname: str = None
-    familyname: str = None
+    lastname: str = None
     gender: str = None
     displayname: str = None
     persid: int = None
@@ -147,11 +147,16 @@ class Person(IAMApi):
     end_date: str = None
     category: str = None
     department: str = None
+    leitzahl: str = None
 
     @property
     def data(self):
         return asdict(self)
 
+    @property
+    def familyname(self):
+        return self.lastname
+
     def get_person(self, identifier):
         endpoint = f"/users/{identifier}"
         data = self.get_request(endpoint=endpoint)
@@ -177,11 +182,14 @@ class Person(IAMApi):
                 if new_person[field]
                 else None
             )
+        if data.get("department"):
+            match = re.search(r"\((?P<leitzahl>\d+)\)", data.get("department"))
+            if match:
+                new_person["leitzahl"] = match.groupdict()["leitzahl"]
 
         person = Person(**new_person)
         person._admin_username = self._admin_username
         person._admin_password = self._admin_password
-        # print(json.dumps(asdict(person), indent=4))
         return person
 
     def delete_user(self, username: str):
@@ -193,7 +201,7 @@ class Person(IAMApi):
 @dataclass
 class PersonLegacy(IAMApiLegacy):
     firstname: str = None
-    familyname: str = None
+    lastname: str = None
     title: str = None
     description: str = None
     mail: str = None
@@ -262,7 +270,7 @@ class PersonLegacy(IAMApiLegacy):
             # TODO: get the new npid from post request?
             if VERBOSE:
                 print(
-                    f"Person {self.firstname} {self.familyname} was successfully {action}"
+                    f"Person {self.firstname} {self.lastname} was successfully {action}"
                 )
         elif resp.status_code == 401:
             raise ValueError(
@@ -277,7 +285,7 @@ class PersonLegacy(IAMApiLegacy):
         username,
         password=None,
         firstname=None,
-        familyname=None,
+        lastname=None,
         mail=None,
         description=None,
     ):
@@ -434,7 +442,7 @@ class Guest(Person):
     def create(
         self,
         firstname: str,
-        familyname: str,
+        lastname: str,
         mail: str,
         host_username: str,
         host_admingroup: str,
@@ -467,11 +475,17 @@ class Guest(Person):
                 "Difference between endDate and startDate is more than 356 days."
             )
 
-        host_person = self.get_person(host_username)
+        person = Person()
+        person._admin_username = self._admin_username
+        person._admin_password = self._admin_password
+        host_person = person.get_person(host_username)
         if not host_person:
             user = self.get_user(host_username)
             host_person = self.get_person(user["npid"])
-        if not host_person:
+
+        if host_person:
+            host_leitzahl = host_person.leitzahl
+        else:
             print(f"no such host: {host_username}")
 
         if host_leitzahl is None:
@@ -486,7 +500,7 @@ class Guest(Person):
             raise ValueError("no host leitzahl for guest provided.")
         if technical_contact is None:
             try:
-                technical_contact = host_person["email"]
+                technical_contact = host_person.mail
             except Exception:
                 pass
             if not technical_contact:
@@ -498,7 +512,7 @@ class Guest(Person):
 
         body = {
             "firstName": firstname,
-            "lastName": familyname,
+            "lastName": lastname,
             "mail": mail,
             "host": host_username,
             "respAdminRole": host_admingroup,
@@ -522,7 +536,11 @@ class Guest(Person):
         }
         endpoint = "/guests"
         data = self.post_request(endpoint=endpoint, body=body)
-        guest = Guest.new_from_data(data)
+        guest = self.new_from_data(data)
         guest._admin_username = self._admin_username
         guest._admin_password = self._admin_password
         return guest
+
+    def delete(self, username):
+        endpoint = f"/guests/{username}"
+        self.delete_request(endpoint=endpoint)
