@@ -1,10 +1,12 @@
-import os
 import json
+import os
+from dataclasses import asdict, dataclass, field
 
-from .person import Person
-from .service import Service, Mailbox
-from .verbose import VERBOSE
+from .conn import IAMApiLegacy
+from .person import PersonLegacy
+from .service import Mailbox, Service
 from .utils import to_date
+from .verbose import VERBOSE
 
 service_map = {
     "LDAP": "LDAP",
@@ -16,67 +18,98 @@ service_map = {
     "WLAN_VPN": "WLAN_VPN",
 }
 
+map_iamlegacyfields2internal = {
+    "username": "username",
+    "sn": "sn",
+    "givenName": "givenName",
+    "nuid": "nuid",
+    "npid": "npid",
+    "uidNumber": "uidNumber",
+    "gidNumber": "gidNumber",
+    "home_directory": "home_directory",
+    "memo": "description",
+    "login_shell": "login_shell",
+    "cre_date": "cre_date",
+    "cre_by": "cre_by",
+    "mod_date": "mod_date",
+    "mod_by": "mod_by",
+    "valid_until": "valid_until",
+    "services": "services",
+}
 
-class User:
-    def __init__(self, conn, data):
-        self.conn = conn
-        self.data = data
-        self.username = None
-        self.npid = None
-        if data:
-            for service in data.get("services", []):
-                service["login_until"] = to_date(service["login_until"]).strftime(
-                    "%Y-%m-%d"
-                )
-                service["delete_after"] = to_date(service["delete_after"]).strftime(
-                    "%Y-%m-%d"
-                )
-            for key in data:
-                if key in ["valid_until", "mod_date", "cre_date"]:
-                    d = to_date(data[key])
-                    data[key] = d.strftime("%Y-%m-%d")
-                setattr(self, key, data[key])
 
-    def __getitem__(self, key):
-        return getattr(self, key, self.data.get(key))
+@dataclass
+class UserLegacy(IAMApiLegacy):
+    username: str = None
+    sn: str = None
+    givenName: str = None
+    npid: int = None
+    nuid: int = None
+    uidNumber: int = None
+    gidNumber: int = None
+    cre_date: str = None
+    cre_by: str = None
+    mod_date: str = None
+    mod_by: str = None
+    valid_until: str = None
+    home_directory: str = None
+    services: list[dict] = field(default_factory=list)
+    description: str = None
+    login_shell: str = None
+
+    @property
+    def data(self):
+        return asdict(self)
 
     def delete(self):
-        endpoint = "/usermgr/person/{}".format(self.username)
-        resp = self.conn._delete_request(endpoint)
+        endpoint = f"usermgr/person/{self.username}"
+        resp = self.delete_request(endpoint)
         if resp.ok:
             if VERBOSE:
-                print("User {} deleted.".format(self.username))
+                print(f"User {self.username} deleted.")
         else:
             data = json.loads(resp.content.decode())
             raise ValueError(data["message"])
 
+    def new_from_data(self, data):
+        new_user = {}
+        for data_field in data:
+            if data_field.lower() in map_iamlegacyfields2internal:
+                new_user[map_iamlegacyfields2internal[data_field.lower()]] = data[
+                    data_field
+                ]
+            else:
+                pass
+
+        for service in new_user.get("services", []):
+            service["login_until"] = to_date(service["login_until"]).strftime(
+                "%Y-%m-%d"
+            )
+            service["delete_after"] = to_date(service["delete_after"]).strftime(
+                "%Y-%m-%d"
+            )
+
+        user = UserLegacy(**new_user)
+        user._admin_username = self._admin_username
+        user._admin_password = self._admin_password
+        return user
+
+    def get_user(self, identifier):
+        endpoint = f"usermgr/user/{identifier}"
+        data = self.get_request(endpoint)
+        return self.new_from_data(data)
+
     def get_person(self):
-        endpoint = "/usermgr/person/{}".format(self.npid)
-        resp = self.conn._get_request(endpoint)
-        data = json.loads(resp.content.decode())
-        if resp.ok:
-            return Person(conn=self, data=data)
-        elif resp.status_code == 401:
-            raise ValueError(
-                "Provided admin-username/password is incorrect or you are not allowed to do this operation"
-            )
-        else:
-            raise ValueError(data["message"])
+        endpoint = f"usermgr/person/{self.npid}"
+        data = self.get_request(endpoint)
+        return PersonLegacy(data=data)
 
     def _to_from_group(self, group_name, action="add", mess="{} {}"):
-        endpoint = "/groupmgr/group/{}/members/{}".format(group_name, action)
+        endpoint = f"/groups/{group_name}/members/{action}"
         body = [self.username]
-        resp = self.conn._put_request(endpoint, body)
-        if resp.ok:
-            if VERBOSE:
-                print(mess.format(self.username, group_name))
-        elif resp.status_code == 401:
-            raise ValueError(
-                "Provided admin-username/password is incorrect or you are not allowed to do this operation"
-            )
-        else:
-            data = json.loads(resp.content.decode())
-            raise ValueError(data["message"])
+        self.put_request(endpoint, body)
+        if VERBOSE:
+            print(mess.format(self.username, group_name))
 
     def add_to_group(self, group_name):
         self._to_from_group(
@@ -89,8 +122,8 @@ class User:
     def grant_service(self, service_name):
         if service_name.upper() in service_map:
             service_name = service_map[service_name.upper()]
-        endpoint = "/usermgr/user/{}/service/{}".format(self.username, service_name)
-        resp = self.conn._post_request(endpoint, {})
+        endpoint = "usermgr/user/{}/service/{}".format(self.username, service_name)
+        resp = self.post_request(endpoint, {})
         if resp.ok:
             if VERBOSE:
                 print("Service {} granted to {}".format(service_name, self.username))
@@ -105,8 +138,8 @@ class User:
     def revoke_service(self, service_name):
         if service_name.upper() in service_map:
             service_name = service_map[service_name.upper()]
-        endpoint = "/usermgr/user/{}/service/{}".format(self.username, service_name)
-        resp = self.conn._delete_request(endpoint)
+        endpoint = "usermgr/user/{}/service/{}".format(self.username, service_name)
+        resp = self.delete_request(endpoint)
         if resp.ok:
             if VERBOSE:
                 print("Service {} revoked from {}".format(service_name, self.username))
@@ -123,20 +156,18 @@ class User:
         if not clean_service_name:
             raise ValueError(f"No such service: {service_name}")
         service_name = clean_service_name
-        endpoint = "/usermgr/user/{}/service/{}".format(self.username, service_name)
-        resp = self.conn._get_request(endpoint)
+        endpoint = "usermgr/user/{}/service/{}".format(self.username, service_name)
+        resp = self.get_request(endpoint)
         data = json.loads(resp.content.decode())
         if resp.ok:
             if service_name == "Mailbox":
                 return Mailbox(
-                    conn=self.conn,
                     username=self.username,
                     service_name=service_name,
                     data=data,
                 )
             else:
                 return Service(
-                    conn=self.conn,
                     username=self.username,
                     service_name=service_name,
                     data=data,
@@ -154,25 +185,6 @@ class User:
         if service_name.upper() not in service_map:
             raise ValueError(f"Cannot set password for service: {service_name}. Sorry!")
 
-        endpoint = "/usermgr/user/{}/service/{}/password".format(
-            self.username, service_map[service_name.upper()]
-        )
+        endpoint = f"usermgr/user/{self.username}/service/{service_map[service_name.upper()]}/password"
         body = {"password": password}
-        resp = self.conn._put_request(endpoint, body)
-
-        if resp.ok:
-            if VERBOSE:
-                print(
-                    "password for user {} and service {} has been successfully changed.".format(
-                        self.username, service_name
-                    )
-                )
-        elif resp.status_code == 401:
-            raise ValueError(
-                "Provided admin-username/password is incorrect or you are not allowed to do this operation"
-            )
-        else:
-            data = json.loads(resp.content.decode())
-            raise ValueError(
-                f"Error: could not set the password for user {self.username} and service {service_name}.\nMessage: {data['message']}"
-            )
+        data = self.put_request(endpoint, body)
